==> gesundheit-0.0.4.tgz: package/lib/normalize.js <==
(function() {
  var norm;
  module.exports = norm = {
    clauses: function(clauses, table, normalizeOp) {
      var clause, constraint, fld, normalized, op, val, _i, _len;
      normalized = [];
      for (_i = 0, _len = clauses.length; _i < _len; _i++) {
        clause = clauses[_i];
        for (fld in clause) {
          constraint = clause[fld];
          if ('object' === typeof constraint) {
            for (op in constraint) {
              val = constraint[op];
              op = normalizeOp(op);
              normalized.push(norm.fieldAndTable({
                field: fld,
                op: op,
                value: val,
                table: table
              }));
            }
          } else {
            normalized.push(norm.fieldAndTable({
              field: fld,
              op: '=',
              value: constraint,
              table: table
            }));
          }
        }
      }
      return normalized;
    },
    orderings: function(orderings, table) {
      var add, direction, field, normalized, ordering, _i, _len, _ref;
      normalized = [];
      add = function(field, direction) {
        direction = (function() {
          switch ((direction || '').toLowerCase()) {
            case 'asc':
            case 'ascending':
              return 'ASC';
            case 'desc':
            case 'descending':
              return 'DESC';
            case '':
              return '';
            default:
              throw new Error("Unsupported ordering direction " + direction);
          }
        })();
        return normalized.push(norm.fieldAndTable({
          field: field,
          table: table,
          direction: direction
        }));
      };
      for (_i = 0, _len = orderings.length; _i < _len; _i++) {
        ordering = orderings[_i];
        if ('string' === typeof ordering) {
          _ref = ordering.split(/\ +/), field = _ref[0], direction = _ref[1];
          add(field, direction);
        } else {
          for (field in ordering) {
            direction = ordering[field];
            add(field, direction);
          }
        }
      }
      return normalized;
    },
    fieldAndTable: function(tableField) {
      var field, table, _ref;
      _ref = tableField.field.split('.'), table = _ref[0], field = _ref[1];
      if (field != null) {
        tableField.table = table;
        tableField.field = field;
      }
      return tableField;
    }
  };
}).call(this);

==> gesundheit-0.1.2.tgz: package/lib/normalize.js <==
(function() {
  var norm;
  module.exports = norm = {
    clauses: function(clauses, table, normalizeOp) {
      var clause, constraint, fld, normalized, op, val, _i, _len;
      normalized = [];
      for (_i = 0, _len = clauses.length; _i < _len; _i++) {
        clause = clauses[_i];
        for (fld in clause) {
          constraint = clause[fld];
          if ('object' === typeof constraint) {
            for (op in constraint) {
              val = constraint[op];
              op = normalizeOp(op);
              normalized.push({
                field: fld,
                op: op,
                value: val,
                table: table
              });
            }
          } else {
            normalized.push({
              field: fld,
              op: '=',
              value: constraint,
              table: table
            });
          }
        }
      }
      return normalized;
    },
    orderings: function(orderings, table) {
      var add, direction, field, normalized, ordering, _i, _len, _ref;
      normalized = [];
      add = function(field, direction) {
        direction = (function() {
          switch ((direction || '').toLowerCase()) {
            case 'asc':
            case 'ascending':
              return 'ASC';
            case 'desc':
            case 'descending':
              return 'DESC';
            case '':
              return '';
            default:
              throw new Error("Unsupported ordering direction " + direction);
          }
        })();
        return normalized.push({
          field: field,
          table: table,
          direction: direction
        });
      };
      for (_i = 0, _len = orderings.length; _i < _len; _i++) {
        ordering = orderings[_i];
        if ('string' === typeof ordering) {
          _ref = ordering.split(/\ +/), field = _ref[0], direction = _ref[1];
          add(field, direction);
        } else {
          for (field in ordering) {
            direction = ordering[field];
            add(field, direction);
          }
        }
      }
      return normalized;
    }
  };
}).call(this);
